@@ -426,7 +426,10 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
     val = self.convert_node(node.value)
     msg = f"Default value for {name}: {typ.name} can only be '...', got {val}"
     is_alias = False
-    if typ.name:
+    if name == "__match_args__" and isinstance(val, tuple):
+      typ = pytd.NamedType("tuple")
+      val = None
+    elif typ.name:
       if pytd_utils.MatchesFullName(typ, _FINAL_IDS):
         if isinstance(node.value, types.Pyval):
           # to_pytd_literal raises an exception if the value is a float, but
@@ -436,10 +439,10 @@ class _GeneratePytdVisitor(visitor.BaseVisitor):
                    f"legal Literal parameter, got {val}")
           else:
             typ = node.value.to_pytd_literal()
-            val = pytd.AnythingType()
+            val = None
         elif isinstance(val, pytd.NamedType):
           typ = pytd.Literal(val)
-          val = pytd.AnythingType()
+          val = None
       elif pytd_utils.MatchesFullName(typ, _TYPE_ALIAS_IDS):
         typ = val
         val = None
@@ -802,6 +805,6 @@ def canonical_pyi(pyi, multiline_args=False, options=None):
   """Rewrite a pyi in canonical form."""
   ast = parse_string(pyi, options=options)
   ast = ast.Visit(visitors.ClassTypeToNamedType())
-  ast = ast.Visit(visitors.CanonicalOrderingVisitor(sort_signatures=True))
+  ast = ast.Visit(visitors.CanonicalOrderingVisitor())
   ast.Visit(visitors.VerifyVisitor())
   return pytd_utils.Print(ast, multiline_args)
