@@ -9,12 +9,19 @@ from pytype.pytd import base_visitor
 from pytype.pytd import pytd
 
 
-class CanonicalOrderingVisitor(base_visitor.Visitor):
-  """Visitor for converting ASTs back to canonical (sorted) ordering."""
+# TODO(rechen): IsNamedTuple is being used to disable visitors that shouldn't
+# operate on generated classes. Should we do the same for dataclasses and attrs?
+def IsNamedTuple(node: pytd.Class):
+  return any(base.name in ("collections.namedtuple", "typing.NamedTuple")
+             for base in node.bases)
 
-  def __init__(self, sort_signatures=False):
-    super().__init__()
-    self.sort_signatures = sort_signatures
+
+class CanonicalOrderingVisitor(base_visitor.Visitor):
+  """Visitor for converting ASTs back to canonical (sorted) ordering.
+
+  Note that this visitor intentionally does *not* sort a function's signatures,
+  as the signature order determines lookup order.
+  """
 
   def VisitTypeDeclUnit(self, node):
     return pytd.TypeDeclUnit(name=node.name,
@@ -24,11 +31,17 @@ class CanonicalOrderingVisitor(base_visitor.Visitor):
                              classes=tuple(sorted(node.classes)),
                              aliases=tuple(sorted(node.aliases)))
 
-  def VisitClass(self, node):
+  def _PreserveConstantsOrdering(self, node):
     # If we have a dataclass-like decorator we need to preserve the order of the
     # class attributes, otherwise inheritance will not work correctly.
     if any(x.name in ("attr.s", "dataclasses.dataclass")
            for x in node.decorators):
+      return True
+    # The order of a namedtuple's fields should always be preserved.
+    return IsNamedTuple(node)
+
+  def VisitClass(self, node):
+    if self._PreserveConstantsOrdering(node):
       constants = node.constants
     else:
       constants = sorted(node.constants)
@@ -43,15 +56,6 @@ class CanonicalOrderingVisitor(base_visitor.Visitor):
         slots=tuple(sorted(node.slots)) if node.slots is not None else None,
         template=node.template)
 
-  def VisitFunction(self, node):
-    # Typically, signatures should *not* be sorted because their order
-    # determines lookup order. But some pytd (e.g., inference output) doesn't
-    # have that property, in which case self.sort_signatures will be True.
-    if self.sort_signatures:
-      return node.Replace(signatures=tuple(sorted(node.signatures)))
-    else:
-      return node
-
   def VisitSignature(self, node):
     return node.Replace(
         template=tuple(sorted(node.template)),
