@@ -250,6 +250,7 @@ class _ToTypeVisitor(Visitor):
     self._in_alias = False
     self._in_literal = 0
     self.allow_singletons = allow_singletons
+    self.allow_functions = False
 
   def EnterAlias(self, _):
     assert not self._in_alias
@@ -267,7 +268,7 @@ class _ToTypeVisitor(Visitor):
 
   def to_type(self, t):
     allow_constants = self._in_alias or self._in_literal
-    allow_functions = self._in_alias
+    allow_functions = self._in_alias or self.allow_functions
     return pytd.ToType(
         t, allow_constants=allow_constants, allow_functions=allow_functions,
         allow_singletons=self.allow_singletons)
@@ -328,6 +329,18 @@ def MaybeSubstituteParameters(base_type, parameters=None):
   return base_type.Visit(ReplaceTypeParameters(mapping))
 
 
+def _MaybeSubstituteParametersInGenericType(node):
+  if isinstance(node.base_type, (pytd.GenericType, pytd.UnionType)):
+    try:
+      node = MaybeSubstituteParameters(
+          node.base_type, node.parameters) or node
+    except ValueError as e:
+      raise KeyError(str(e)) from e
+  elif isinstance(node.base_type, pytd.AnythingType):
+    return node.base_type
+  return node
+
+
 class LookupExternalTypes(_RemoveTypeParametersFromGenericAny, _ToTypeVisitor):
   """Look up NamedType pointers using a symbol table."""
 
@@ -481,13 +494,7 @@ class LookupExternalTypes(_RemoveTypeParametersFromGenericAny, _ToTypeVisitor):
       return new_type
 
   def VisitGenericType(self, node):
-    if isinstance(node.base_type, (pytd.GenericType, pytd.UnionType)):
-      try:
-        node = MaybeSubstituteParameters(
-            node.base_type, node.parameters) or node
-      except ValueError as e:
-        raise KeyError(str(e)) from e
-    return node
+    return _MaybeSubstituteParametersInGenericType(node)
 
   def _ModulePrefix(self):
     return self.name + "." if self.name else ""
@@ -756,6 +763,9 @@ class LookupLocalTypes(_RemoveTypeParametersFromGenericAny, _ToTypeVisitor):
         t.cls = cast(pytd.ClassType, self.VisitNamedType(lookup_type)).cls
     return t
 
+  def VisitGenericType(self, node):
+    return _MaybeSubstituteParametersInGenericType(node)
+
 
 class ReplaceTypes(Visitor):
   """Visitor for replacing types in a tree.
