@@ -652,7 +652,8 @@ def _overrides(subcls, supercls, attr):
         break
       if isinstance(cls, mixin.LazyMembers):
         cls.load_lazy_attribute(attr)
-      if attr in cls.members and cls.members[attr].bindings:
+      if (isinstance(cls, abstract.SimpleValue) and attr in cls.members and
+          cls.members[attr].bindings):
         return True
   return False
 
@@ -735,8 +736,6 @@ def call_binary_operator(state, name, x, y, report_errors, ctx):
         if ctx.options.report_errors:
           ctx.errorlog.unsupported_operands(ctx.vm.frames, name, x, y)
         result = ctx.new_unsolvable(state.node)
-    elif isinstance(error, function.DictKeyMissing):
-      state, result = error.get_return(state)
     else:
       if ctx.options.report_errors:
         ctx.errorlog.invalid_function_call(ctx.vm.frames, error)
